#HOW TO USE(SYNTAX):
import SaduStatistics as SS
from SaduStatistics import CentralTendency
from SaduStatistics import VarianceMeasures
from SaduStatistics import InferentialStatistics

SS.CentralTendency.MEAN(***ARGUMENTS***)
SS.CentralTendency.MODE(***ARGUMENTS***)
SS.CentralTendency.MEDIAN(***ARGUMENTS***)

SS.VarianceMeasures.RANGE(***ARGUMENTS***)
SS.VarianceMeasures.VARIANCE(***ARGUMENTS***)
SS.VarianceMeasures.StandardDeviation(***ARGUMENTS***)
SS.VarianceMeasures.InterQuartile(***ARGUMENTS***)

SS.InferentialStatistics.HypothesisTesting(***ARGUMENTS***)
SS.InferentialStatistics.ConfidenceInterval(***ARGUMENTS***)
SS.InferentialStatistics.LinearRegressionModel(***ARGUMENTS***)
SS.InferentialStatistics.MatplotlibHistogram(***ARGUMENTS***)
SS.InferentialStatistics.HistPlot(***ARGUMENTS***)
SS.InferentialStatistics.DOT(***ARGUMENTS***)


#SECOND INSTALL REQUIREMENTS(LIBRARIES):
1. matplotlib
2. math
3. scipy
4. sklearn
5. numpy


***Statistical functions on this package version are classified into three sections: 1- CentralTendency, 2-VarianceMeasures and 3-InferentialStatistics; alongside histogram plot function. Example of usage: SaduStatistics.CentralTendency.Mean(***arguments***), OR SaduStatistics.VarianceMeasures.InterQuartile(***arguments***) OR SaduStatistics.InferentialStatistics.HypothesisTesting(***arguments***)